@@ -46,11 +46,11 @@ THE SOFTWARE.
 #endif
 
 #if OGRE_RESOURCEMANAGER_STRICT == 0
-#   define OGRE_RESOURCE_GROUP_INIT = ResourceGroupManager::AUTODETECT_RESOURCE_GROUP_NAME
+#   define OGRE_RESOURCE_GROUP_INIT = RGN_AUTODETECT
 #elif OGRE_RESOURCEMANAGER_STRICT == 1
 #   define OGRE_RESOURCE_GROUP_INIT
 #else
-#   define OGRE_RESOURCE_GROUP_INIT = ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME
+#   define OGRE_RESOURCE_GROUP_INIT = RGN_DEFAULT
 #endif
 
 namespace Ogre {
@@ -61,9 +61,17 @@ namespace Ogre {
     /** \addtogroup Resources
     *  @{
     */
+
+    /// Default resource group name
+    _OgreExport extern const char* const RGN_DEFAULT;
+    /// Internal resource group name (should be used by OGRE internal only)
+    _OgreExport extern const char* const RGN_INTERNAL;
+    /// Special resource group name which causes resource group to be automatically determined based on searching for the resource in all groups.
+    _OgreExport extern const char* const RGN_AUTODETECT;
+
     /** This class defines an interface which is called back during
         resource group loading to indicate the progress of the load. 
-    @remarks
+
         Resource group loading is in 2 phases - creating resources from 
         declarations (which includes parsing scripts), and loading
         resources. Note that you don't necessarily have to have both; it
@@ -194,9 +202,10 @@ namespace Ogre {
     };
 
     /**
-     @remarks   This class allows users to override resource loading behavior.
-                By overriding this class' methods, you can change how resources
-                are loaded and the behavior for resource name collisions.
+    This class allows users to override resource loading behavior.
+
+    By overriding this class' methods, you can change how resources
+    are loaded and the behavior for resource name collisions.
     */
     class ResourceLoadingListener
     {
@@ -207,7 +216,7 @@ namespace Ogre {
         virtual DataStreamPtr resourceLoading(const String &name, const String &group, Resource *resource) = 0;
 
         /** This event is called when a resource stream has been opened, but not processed yet. 
-        @remarks
+
             You may alter the stream if you wish or alter the incoming pointer to point at
             another stream if you wish.
         */
@@ -215,7 +224,9 @@ namespace Ogre {
 
         /** This event is called when a resource collides with another existing one in a resource manager
 
-            return false to skip registration of the conflicting resource and continue using the previous instance.
+            @param resource the new resource that conflicts with an existing one
+            @param resourceManager the according resource manager 
+            @return false to skip registration of the conflicting resource and continue using the previous instance.
           */
         virtual bool resourceCollision(Resource *resource, ResourceManager *resourceManager) = 0;
     };
@@ -225,53 +236,24 @@ namespace Ogre {
         resources in a group. It also provides facilities to monitor resource
         loading per group (to do progress bars etc), provided the resources 
         that are required are pre-registered.
-    @par
-        Defining new resource groups,  and declaring the resources you intend to
+
+        Defining new resource groups, and declaring the resources you intend to
         use in advance is optional, however it is a very useful feature. In addition, 
         if a ResourceManager supports the definition of resources through scripts, 
         then this is the class which drives the locating of the scripts and telling
         the ResourceManager to parse them. 
-    @par
-        There are several states that a resource can be in (the concept, not the
-        object instance in this case):
-        <ol>
-        <li><b>Undefined</b>. Nobody knows about this resource yet. It might be
-        in the filesystem, but Ogre is oblivious to it at the moment - there 
-        is no Resource instance. This might be because it's never been declared
-        (either in a script, or using #declareResource), or
-        it may have previously been a valid Resource instance but has been 
-        removed, either individually through ResourceManager::remove or as a group
-        through #clearResourceGroup.</li>
-        <li><b>Declared</b>. Ogre has some forewarning of this resource, either
-        through calling #declareResource, or by declaring
-        the resource in a script file which is on one of the resource locations
-        which has been defined for a group. There is still no instance of Resource,
-        but Ogre will know to create this resource when 
-        #initialiseResourceGroup is called (which is automatic
-        if you declare the resource group before Root::initialise).</li>
-        <li><b>Unloaded</b>. There is now a Resource instance for this resource, 
-        although it is not loaded. This means that code which looks for this
-        named resource will find it, but the Resource is not using a lot of memory
-        because it is in an unloaded state. A Resource can get into this state
-        by having just been created by #initialiseResourceGroup
-        (either from a script, or from a call to #declareResource), by
-        being created directly from code (ResourceManager::createResource), or it may
-        have previously been loaded and has been unloaded, either individually
-        through Resource::unload, or as a group through #unloadResourceGroup.</li>
-        <li><b>Loaded</b>The Resource instance is fully loaded. This may have
-        happened implicitly because something used it, or it may have been 
-        loaded as part of a group.</li>
-        </ol>
+        
+        @see @ref Resource-Management
     */
     class _OgreExport ResourceGroupManager : public Singleton<ResourceGroupManager>, public ResourceAlloc
     {
     public:
         OGRE_AUTO_MUTEX; // public to allow external locking
-        /// Default resource group name
+        /// same as @ref RGN_DEFAULT
         static const String DEFAULT_RESOURCE_GROUP_NAME;
-        /// Internal resource group name (should be used by OGRE internal only)
+        /// same as @ref RGN_INTERNAL
         static const String INTERNAL_RESOURCE_GROUP_NAME;
-        /// Special resource group name which causes resource group to be automatically determined based on searching for the resource in all groups.
+        /// same as @ref RGN_AUTODETECT
         static const String AUTODETECT_RESOURCE_GROUP_NAME;
         /// The number of reference counts held per resource by the resource system
         static const long RESOURCE_SYSTEM_NUM_REFERENCE_COUNTS;
@@ -441,73 +423,16 @@ namespace Ogre {
         virtual ~ResourceGroupManager();
 
         /** Create a resource group.
-        @remarks
-            A resource group allows you to define a set of resources that can 
-            be loaded / unloaded as a unit. For example, it might be all the 
-            resources used for the level of a game. There is always one predefined
-            resource group called #DEFAULT_RESOURCE_GROUP_NAME,
-            which is typically used to hold all resources which do not need to 
-            be unloaded until shutdown. There is another predefined resource
-            group called #INTERNAL_RESOURCE_GROUP_NAME too,
-            which should be used by OGRE internal only, the resources created
-            in this group aren't supposed to modify, unload or remove by user.
-            You can create additional ones so that you can control the life of
-            your resources in whichever way you wish.
-            There is one other predefined value, 
-            #AUTODETECT_RESOURCE_GROUP_NAME; using this
-            causes the group name to be derived at load time by searching for 
-            the resource in the resource locations of each group in turn.
-        @par
-            Once you have defined a resource group, resources which will be loaded
-            as part of it are defined in one of 3 ways:
-            <ol>
-            <li>Manually through declareResource(); this is useful for scripted
-                declarations since it is entirely generalised, and does not 
-                create Resource instances right away</li>
-            <li>Through the use of scripts; some ResourceManager subtypes have
-                script formats (e.g. .material, .overlay) which can be used
-                to declare resources</li>
-            <li>By calling ResourceManager::createResource to create a resource manually.
-            This resource will go on the list for it's group and will be loaded
-            and unloaded with that group</li>
-            </ol>
-            You must remember to call #initialiseResourceGroup if you intend to use
-            the first 2 types.
+
         @param name The name to give the resource group.
         @param inGlobalPool if true the resource will be loaded even a different
             group was requested in the load method as a parameter.
+        @see @ref Resource-Management
         */
         void createResourceGroup(const String& name, bool inGlobalPool = !OGRE_RESOURCEMANAGER_STRICT);
 
 
         /** Initialises a resource group.
-        @remarks
-            After creating a resource group, adding some resource locations, and
-            perhaps pre-declaring some resources using #declareResource, but
-            before you need to use the resources in the group, you 
-            should call this method to initialise the group. By calling this,
-            you are triggering the following processes:
-            <ol>
-            <li>Scripts for all resource types which support scripting are
-                parsed from the resource locations, and resources within them are
-                created (but not loaded yet).</li>
-            <li>Creates all the resources which have just pre-declared using
-            declareResource (again, these are not loaded yet)</li>
-            </ol>
-            So what this essentially does is create a bunch of unloaded Resource entries
-            in the respective ResourceManagers based on scripts, and resources
-            you've pre-declared. That means that code looking for these resources
-            will find them, but they won't be taking up much memory yet, until
-            they are either used, or they are loaded in bulk using loadResourceGroup.
-            Loading the resource group in bulk is entirely optional, but has the 
-            advantage of coming with progress reporting as resources are loaded.
-        @par
-            Failure to call this method means that #loadResourceGroup will do
-            nothing, and any resources you define in scripts will not be found.
-            Similarly, once you have called this method you won't be able to
-            pick up any new scripts or pre-declared resources, unless you
-            call clearResourceGroup, set up declared resources, and call this
-            method again.
         @note 
             When you call Root::initialise, all resource groups that have already been
             created are automatically initialised too. Therefore you do not need to 
@@ -518,6 +443,7 @@ namespace Ogre {
             method for the groups you create after this.
 
         @param name The name of the resource group to initialise
+        @see @ref Resource-Management
         */
         void initialiseResourceGroup(const String& name);
 
@@ -640,29 +566,7 @@ namespace Ogre {
 
         /** Adds a location to the list of searchable locations for a
             Resource type.
-            @remarks
-                Resource files (textures, models etc) need to be loaded from
-                specific locations. By calling this method, you add another
-                search location to the list. Locations added first are preferred
-                over locations added later.
-            @par
-                Locations can be folders, compressed archives, even perhaps
-                remote locations. Facilities for loading from different
-                locations are provided by plugins which provide
-                implementations of the Archive class.
-                All the application user has to do is specify a 'loctype'
-                string in order to indicate the type of location, which
-                should map onto one of the provided plugins. Ogre comes
-                configured with the 'FileSystem' (folders) and 'Zip' (archive
-                compressed with the pkzip / WinZip etc utilities) types.
-            @par
-                You can also supply the name of a resource group which should
-                have this location applied to it. The
-                #DEFAULT_RESOURCE_GROUP_NAME group is the
-                default, and one resource group which will always exist. You
-                should consider defining resource groups for your more specific
-                resources (e.g. per level) so that you can control loading /
-                unloading better.
+
             @param
                 name The name of the location, e.g. './data' or
                 '/compressed/gamedata.zip'
@@ -682,7 +586,7 @@ namespace Ogre {
                 The default is to disable this so that resources in subdirectories
                 with the same name are still unique.
             @param readOnly whether the Archive is read only
-            @see Archive
+            @see @ref Resource-Management
         */
         void addResourceLocation(const String& name, const String& locType, 
             const String& resGroup = DEFAULT_RESOURCE_GROUP_NAME, bool recursive = false, bool readOnly = true);
@@ -695,20 +599,7 @@ namespace Ogre {
 
         /** Declares a resource to be a part of a resource group, allowing you 
             to load and unload it as part of the group.
-        @remarks
-            By declaring resources before you attempt to use them, you can 
-            more easily control the loading and unloading of those resources
-            by their group. Declaring them also allows them to be enumerated, 
-            which means events can be raised to indicate the loading progress
-            (@see ResourceGroupListener). Note that another way of declaring
-            resources is to use a script specific to the resource type, if
-            available (e.g. .material).
-        @par
-            Declared resources are not created as Resource instances (and thus
-            are not available through their ResourceManager) until initialiseResourceGroup
-            is called, at which point all declared resources will become created 
-            (but unloaded) Resource instances, along with any resources declared
-            in scripts in resource locations associated with the group.
+
         @param name The resource name. 
         @param resourceType The type of the resource. Ogre comes preconfigured with 
             a number of resource types: 
@@ -726,6 +617,7 @@ namespace Ogre {
         @param loadParameters A list of name / value pairs which supply custom
             parameters to the resource which will be required before it can 
             be loaded. These are specific to the resource type.
+        @see @ref Resource-Management
         */
         void declareResource(const String& name, const String& resourceType,
             const String& groupName = DEFAULT_RESOURCE_GROUP_NAME,
