@@ -216,36 +216,20 @@ namespace Ogre {
         */
         const AxisAlignedBox& _getWorldAABB(void) const { return mWorldAABB; }
 
-        /** Retrieves an iterator which can be used to efficiently step through the objects 
-            attached to this node.
-        @remarks
-            This is a much faster way to go through <B>all</B> the objects attached to the node
-            than using getAttachedObject. But the iterator returned is only valid until a change
-            is made to the collection (ie an addition or removal) so treat the returned iterator
-            as transient, and don't add / remove items as you go through the iterator, save changes
-            until the end, or retrieve a new iterator after making the change. Making changes to
-            the object returned through the iterator is OK though.
-        @deprecated use getAttachedObjects()
-        */
-        ObjectIterator getAttachedObjectIterator(void) {
+        /// @deprecated use getAttachedObjects()
+        OGRE_DEPRECATED ObjectIterator getAttachedObjectIterator(void) {
             return ObjectIterator(mObjectsByName.begin(), mObjectsByName.end());
         }
-        /** Retrieves an iterator which can be used to efficiently step through the objects 
-            attached to this node.
-        @remarks
-            This is a much faster way to go through <B>all</B> the objects attached to the node
-            than using getAttachedObject. But the iterator returned is only valid until a change
-            is made to the collection (ie an addition or removal) so treat the returned iterator
-            as transient, and don't add / remove items as you go through the iterator, save changes
-            until the end, or retrieve a new iterator after making the change. Making changes to
-            the object returned through the iterator is OK though.
-        @deprecated use getAttachedObjects()
-        */
-        ConstObjectIterator getAttachedObjectIterator(void) const {
+        /// @deprecated use getAttachedObjects()
+        OGRE_DEPRECATED ConstObjectIterator getAttachedObjectIterator(void) const {
             return ConstObjectIterator(mObjectsByName.begin(), mObjectsByName.end());
         }
 
-        /// The MovableObjects associated with this node
+        /** The MovableObjects attached to this node
+         *
+         * This is a much faster way to go through <B>all</B> the objects attached to the node than
+         * using getAttachedObject.
+         */
         const ObjectMap& getAttachedObjects() const {
             return mObjectsByName;
         }
