@@ -202,8 +202,9 @@ namespace Ogre
             CE_DUPLICATEOVERRIDE,
             CE_UNEXPECTEDTOKEN,
             CE_OBJECTBASENOTFOUND,
-            CE_UNSUPPORTEDBYRENDERSYSTEM,
-            CE_REFERENCETOANONEXISTINGOBJECT
+            CE_UNSUPPORTEDBYRENDERSYSTEM, //!< @deprecated do not use
+            CE_REFERENCETOANONEXISTINGOBJECT,
+            CE_DEPRECATEDSYMBOL
         };
         static String formatErrorCode(uint32 code);
     public:
@@ -862,6 +863,10 @@ namespace Ogre
 
         // added during 1.11. re-sort for 1.12
         ID_LINE_WIDTH,
+        ID_SAMPLER,
+        ID_SAMPLER_REF,
+        ID_THREAD_GROUPS,
+        ID_RENDER_CUSTOM,
 
         ID_END_BUILTIN_IDS
     };
